# THIS FILE IS GENERATED FROM ENSTALLER SETUP.PY
version = '4.8.8'
full_version = '4.8.8'
git_revision = 'ad36f4a87d6456b837a7e9f95166d934602437ad'
is_released = True

if not is_released:
    version = full_version
